==> ejc-oa-impl-3.0.0-20250813.025730-244-sources.jar: com/ejianc/business/oa/vo/MattersApplyVO.java <==
package com.ejianc.business.oa.vo;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;

import java.util.ArrayList;
import java.util.Date;
import java.util.List;


/**
 * 事项申请实体
 * 
 * @author generator
 * 
 */
public class MattersApplyVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private Integer dependOnProject; // 是否属于项目(1-是,0-否)
    private Long projectId; // 项目
    private String projectName; // 项目名称
    private Long mattersTypeId; // 事项类型
    private String mattersTypeName; // 事项类型名称
    private Long typeId; // 类型
    private String typeName; // 类型名称
    private Long orgId; // 组织
    private String orgName; // 组织名称
    private String billCode; // 申请编号
    private String place; // 地点
    @JsonFormat(pattern = "yyyy-MM-dd HH:mm", timezone = "GMT+8")
    private Date beginTime; // 开始日期
    @JsonFormat(pattern = "yyyy-MM-dd HH:mm", timezone = "GMT+8")
    private Date endTime; // 结束日期
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date applyTime; // 申请日期
    private Integer billState; // 单据状态（审批必须字段）
    private Long applierId; // 申请人
    private String applierName; // 申请人名称
    private String applierDepartmentName; // 申请部门名称
    private String billStateName; //单据状态名称
    private String useBy; // 被哪个单据使用 费用报销payReimburse 零星付款paySporadic
    private String memo; // 申请说明
    private String def1; // 自定义字段1
    private String def2; // 自定义字段2
    private String def3; // 自定义字段3
    private String def4; // 自定义字段4
    private String def5; // 自定义字段5
    private String def6; // 自定义字段6
    private String def7; // 自定义字段7
    private String def8; // 自定义字段8
    private String def9; // 自定义字段9
    private String def10; // 自定义字段10
    private List<MattersApplyDetailVO> mattersApplyDetailList = new ArrayList<>(); // 事项申请实体明细

    public String getUseBy() {
        return useBy;
    }

    public void setUseBy(String useBy) {
        this.useBy = useBy;
    }

    public List<MattersApplyDetailVO> getMattersApplyDetailList() {
        return mattersApplyDetailList;
    }

    public void setMattersApplyDetailList(List<MattersApplyDetailVO> mattersApplyDetailList) {
        this.mattersApplyDetailList = mattersApplyDetailList;
    }

    public String getBillStateName() {
        return billStateName;
    }

    public void setBillStateName(String billStateName) {
        this.billStateName = billStateName;
    }

    public Integer getDependOnProject() {
        return dependOnProject;
    }

    public void setDependOnProject(Integer dependOnProject) {
        this.dependOnProject = dependOnProject;
    }
    @ReferSerialTransfer(referCode="market-project")
    public Long getProjectId() {
        return projectId;
    }
    @ReferDeserialTransfer
    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    @ReferSerialTransfer(referCode = "support-defdoc")
    public Long getMattersTypeId() {
        return mattersTypeId;
    }
    @ReferDeserialTransfer
    public void setMattersTypeId(Long mattersTypeId) {
        this.mattersTypeId = mattersTypeId;
    }
    public String getMattersTypeName() {
        return mattersTypeName;
    }

    public void setMattersTypeName(String mattersTypeName) {
        this.mattersTypeName = mattersTypeName;
    }
    @ReferSerialTransfer(referCode = "support-defdoc")
    public Long getTypeId() {
        return typeId;
    }
    @ReferDeserialTransfer
    public void setTypeId(Long typeId) {
        this.typeId = typeId;
    }

    public String getTypeName() {
        return typeName;
    }

    public void setTypeName(String typeName) {
        this.typeName = typeName;
    }
    @ReferSerialTransfer(referCode="idm-org")
    public Long getOrgId() {
        return orgId;
    }
    @ReferDeserialTransfer
    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public String getPlace() {
        return place;
    }

    public void setPlace(String place) {
        this.place = place;
    }
    public Date getBeginTime() {
        return beginTime;
    }

    public void setBeginTime(Date beginTime) {
        this.beginTime = beginTime;
    }
    public Date getEndTime() {
        return endTime;
    }

    public void setEndTime(Date endTime) {
        this.endTime = endTime;
    }
    public Date getApplyTime() {
        return applyTime;
    }

    public void setApplyTime(Date applyTime) {
        this.applyTime = applyTime;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    @ReferSerialTransfer(referCode="idm-employee")
    public Long getApplierId() {
        return applierId;
    }
    @ReferDeserialTransfer
    public void setApplierId(Long applierId) {
        this.applierId = applierId;
    }
    public String getApplierName() {
        return applierName;
    }

    public void setApplierName(String applierName) {
        this.applierName = applierName;
    }
    public String getApplierDepartmentName() {
        return applierDepartmentName;
    }

    public void setApplierDepartmentName(String applierDepartmentName) {
        this.applierDepartmentName = applierDepartmentName;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public String getDef1() {
        return def1;
    }

    public void setDef1(String def1) {
        this.def1 = def1;
    }
    public String getDef2() {
        return def2;
    }

    public void setDef2(String def2) {
        this.def2 = def2;
    }
    public String getDef3() {
        return def3;
    }

    public void setDef3(String def3) {
        this.def3 = def3;
    }
    public String getDef4() {
        return def4;
    }

    public void setDef4(String def4) {
        this.def4 = def4;
    }
    public String getDef5() {
        return def5;
    }

    public void setDef5(String def5) {
        this.def5 = def5;
    }
    public String getDef6() {
        return def6;
    }

    public void setDef6(String def6) {
        this.def6 = def6;
    }
    public String getDef7() {
        return def7;
    }

    public void setDef7(String def7) {
        this.def7 = def7;
    }
    public String getDef8() {
        return def8;
    }

    public void setDef8(String def8) {
        this.def8 = def8;
    }
    public String getDef9() {
        return def9;
    }

    public void setDef9(String def9) {
        this.def9 = def9;
    }
    public String getDef10() {
        return def10;
    }

    public void setDef10(String def10) {
        this.def10 = def10;
    }
    
}

==> ejc-oa-impl-3.0.0-20250813.065303-245-sources.jar: com/ejianc/business/oa/vo/MattersApplyVO.java <==
package com.ejianc.business.oa.vo;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;

import java.util.ArrayList;
import java.util.Date;
import java.util.List;


/**
 * 事项申请实体
 * 
 * @author generator
 * 
 */
public class MattersApplyVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private Integer dependOnProject; // 是否属于项目(1-是,0-否)
    private Long projectId; // 项目
    private String projectName; // 项目名称
    private Long mattersTypeId; // 事项类型
    private String mattersTypeName; // 事项类型名称
    private Long typeId; // 类型
    private String typeName; // 类型名称
    private Long orgId; // 组织
    private String orgName; // 组织名称
    private String billCode; // 申请编号
    private String place; // 地点
    @JsonFormat(pattern = "yyyy-MM-dd HH:mm", timezone = "GMT+8")
    private Date beginTime; // 开始日期
    @JsonFormat(pattern = "yyyy-MM-dd HH:mm", timezone = "GMT+8")
    private Date endTime; // 结束日期
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date applyTime; // 申请日期
    private Integer billState; // 单据状态（审批必须字段）
    private Long applierId; // 申请人
    private String applierName; // 申请人名称
    private String applierDepartmentName; // 申请部门名称
    private String billStateName; //单据状态名称
    private String useBy; // 被哪个单据使用 费用报销payReimburse 零星付款paySporadic
    private Integer days; // 天数
    private String memo; // 申请说明
    private String def1; // 自定义字段1
    private String def2; // 自定义字段2
    private String def3; // 自定义字段3
    private String def4; // 自定义字段4
    private String def5; // 自定义字段5
    private String def6; // 自定义字段6
    private String def7; // 自定义字段7
    private String def8; // 自定义字段8
    private String def9; // 自定义字段9
    private String def10; // 自定义字段10
    private List<MattersApplyDetailVO> mattersApplyDetailList = new ArrayList<>(); // 事项申请实体明细

    public Integer getDays() {
        return days;
    }

    public void setDays(Integer days) {
        this.days = days;
    }

    public String getUseBy() {
        return useBy;
    }

    public void setUseBy(String useBy) {
        this.useBy = useBy;
    }

    public List<MattersApplyDetailVO> getMattersApplyDetailList() {
        return mattersApplyDetailList;
    }

    public void setMattersApplyDetailList(List<MattersApplyDetailVO> mattersApplyDetailList) {
        this.mattersApplyDetailList = mattersApplyDetailList;
    }

    public String getBillStateName() {
        return billStateName;
    }

    public void setBillStateName(String billStateName) {
        this.billStateName = billStateName;
    }

    public Integer getDependOnProject() {
        return dependOnProject;
    }

    public void setDependOnProject(Integer dependOnProject) {
        this.dependOnProject = dependOnProject;
    }
    @ReferSerialTransfer(referCode="market-project")
    public Long getProjectId() {
        return projectId;
    }
    @ReferDeserialTransfer
    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    @ReferSerialTransfer(referCode = "support-defdoc")
    public Long getMattersTypeId() {
        return mattersTypeId;
    }
    @ReferDeserialTransfer
    public void setMattersTypeId(Long mattersTypeId) {
        this.mattersTypeId = mattersTypeId;
    }
    public String getMattersTypeName() {
        return mattersTypeName;
    }

    public void setMattersTypeName(String mattersTypeName) {
        this.mattersTypeName = mattersTypeName;
    }
    @ReferSerialTransfer(referCode = "support-defdoc")
    public Long getTypeId() {
        return typeId;
    }
    @ReferDeserialTransfer
    public void setTypeId(Long typeId) {
        this.typeId = typeId;
    }

    public String getTypeName() {
        return typeName;
    }

    public void setTypeName(String typeName) {
        this.typeName = typeName;
    }
    @ReferSerialTransfer(referCode="idm-org")
    public Long getOrgId() {
        return orgId;
    }
    @ReferDeserialTransfer
    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public String getPlace() {
        return place;
    }

    public void setPlace(String place) {
        this.place = place;
    }
    public Date getBeginTime() {
        return beginTime;
    }

    public void setBeginTime(Date beginTime) {
        this.beginTime = beginTime;
    }
    public Date getEndTime() {
        return endTime;
    }

    public void setEndTime(Date endTime) {
        this.endTime = endTime;
    }
    public Date getApplyTime() {
        return applyTime;
    }

    public void setApplyTime(Date applyTime) {
        this.applyTime = applyTime;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    @ReferSerialTransfer(referCode="idm-employee")
    public Long getApplierId() {
        return applierId;
    }
    @ReferDeserialTransfer
    public void setApplierId(Long applierId) {
        this.applierId = applierId;
    }
    public String getApplierName() {
        return applierName;
    }

    public void setApplierName(String applierName) {
        this.applierName = applierName;
    }
    public String getApplierDepartmentName() {
        return applierDepartmentName;
    }

    public void setApplierDepartmentName(String applierDepartmentName) {
        this.applierDepartmentName = applierDepartmentName;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public String getDef1() {
        return def1;
    }

    public void setDef1(String def1) {
        this.def1 = def1;
    }
    public String getDef2() {
        return def2;
    }

    public void setDef2(String def2) {
        this.def2 = def2;
    }
    public String getDef3() {
        return def3;
    }

    public void setDef3(String def3) {
        this.def3 = def3;
    }
    public String getDef4() {
        return def4;
    }

    public void setDef4(String def4) {
        this.def4 = def4;
    }
    public String getDef5() {
        return def5;
    }

    public void setDef5(String def5) {
        this.def5 = def5;
    }
    public String getDef6() {
        return def6;
    }

    public void setDef6(String def6) {
        this.def6 = def6;
    }
    public String getDef7() {
        return def7;
    }

    public void setDef7(String def7) {
        this.def7 = def7;
    }
    public String getDef8() {
        return def8;
    }

    public void setDef8(String def8) {
        this.def8 = def8;
    }
    public String getDef9() {
        return def9;
    }

    public void setDef9(String def9) {
        this.def9 = def9;
    }
    public String getDef10() {
        return def10;
    }

    public void setDef10(String def10) {
        this.def10 = def10;
    }
    
}
